<?php

add_action( 'wp_enqueue_scripts', 'nineteenjr_enqueue_styles' );
add_action( 'customize_register', 'nineteenjr_customize_register' );
add_action( 'customize_controls_enqueue_scripts', 'nineteenjr_customize_control_js' );

load_child_theme_textdomain( 'nineteenjr' );

function nineteenjr_enqueue_styles() {
    
    $parent_style = 'parent-style';
 
    wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css' );

    wp_enqueue_style( 'nineteenjr-child-style',
        get_stylesheet_directory_uri() . '/style.css',
        array( $parent_style ),
        wp_get_theme()->get('Version')
    );
}

function nineteenjr_customize_register( $wp_customize ) {

    // Homepage Settings
    $post_columns_on_front_setting = $wp_customize->add_setting(
        'post_columns_on_front',
        array(
            'default'    => '1',
            'type'       => 'option',
            'capability' => 'manage_options',
            'sanitize_callback' => 'nineteenjr_sanitize_option_post_columns_on_front'
        )
    );

    $wp_customize->add_control(
        'post_columns_on_front_control',
        array(
            'label'   => esc_html__( 'Number of columns', 'nineteenjr' ),
            'description'   => esc_html__( 'Number of columns to display posts in', 'nineteenjr' ),
            'section' => 'static_front_page',
            'type'    => 'radio',
            'settings' => 'post_columns_on_front',
            'choices' => array(
                '1' => esc_html__( 'One', 'nineteenjr' ),
                '2'  => esc_html__( 'Two', 'nineteenjr' )
            ),
        )
    );

    $wp_customize->add_setting(
        'posts_on_front_content',
        array(
            'default'    => 'content',
            'type'       => 'option',
            'capability' => 'manage_options',
            'sanitize_callback' => 'nineteenjr_sanitize_option_posts_on_front_content'
        )
    );

    $wp_customize->add_control(
        'posts_on_front_content_control',
        array(
            'label'   => esc_html__( 'Post content', 'nineteenjr' ),
            'section' => 'static_front_page',
            'type'    => 'radio',
            'settings' => 'posts_on_front_content',
            'choices' => array(
                'content' => esc_html__( 'Show content', 'nineteenjr' ),
                'excerpt'  => esc_html__( 'Show excerpt', 'nineteenjr' )
            ),
        )
    );
}

function nineteenjr_customize_control_js() {
    wp_enqueue_script(
        'nineteenjr-customize-front-posts',
        get_stylesheet_directory_uri() . '/customize-front-posts.js',
        array( 'customize-controls' ),
        '0.0.1',
        true
    );
}

function nineteenjr_sanitize_option_post_columns_on_front($value) {
    return (false !== array_search($value, array('1', '2'))) ? $value : '1';
}

function nineteenjr_sanitize_option_posts_on_front_content($value, $option) {
    return (false !== array_search($value, array('content', 'excerpt'))) ? $value : 'content';
}
